jacinle.utils.value\_scheduler
==============================

.. automodule:: jacinle.utils.value_scheduler

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ConstantScheduler
      LinearScheduler
      MonotonicSchedulerBase
      ValueScheduler
   
   

   
   
   

   
   
   








.. rubric:: Class ConstantScheduler
.. autoclass:: ConstantScheduler
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LinearScheduler
.. autoclass:: LinearScheduler
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MonotonicSchedulerBase
.. autoclass:: MonotonicSchedulerBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ValueScheduler
.. autoclass:: ValueScheduler
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







